@@ -64,7 +64,7 @@ class PristineTar(Command):
         @param archive: the name of the orig archive
         @type archive: C{str}
         """
-        self.run_error = 'Pristine-tar couldn\'t checkout "%s": {stderr}' % os.path.basename(archive)
+        self.run_error = 'Pristine-tar couldn\'t checkout "%s": {stderr_or_reason}' % os.path.basename(archive)
         self.__call__(['checkout', archive])
 
     def commit(self, archive, upstream):
@@ -77,6 +77,12 @@ class PristineTar(Command):
         @param upstream: the upstream branch to diff against
         @type upstream: C{str}
         """
-        self.run_error = ("Couldn't commit to '%s' with upstream '%s': {stderr}" %
+        self.run_error = ("Couldn't commit to '%s' with upstream '%s': {stderr_or_reason}" %
                           (self.branch, upstream))
         self.__call__(['commit', archive, upstream])
+
+    def verify(self, archive):
+        """Verify an archive's I{archive} checksum using to the pristine tar branch"""
+
+        self.run_error = 'Pristine-tar couldn\'t verify "%s": {stderr_or_reason}' % os.path.basename(archive)
+        self.__call__(['verify', archive])
