@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2006-2016 Guido Günther <agx@sigxcpu.org>
+# (C) 2006-2017 Guido Günther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -111,6 +111,7 @@ def prepare_upstream_tarball(repo, cp, options, tarball_dir, output_dir):
             upstream_tree = git_archive_build_orig(repo, cp, output_dir, options)
             if options.pristine_tar_commit:
                 pristine_tar_commit(repo, cp, options, output_dir, orig_files[0], upstream_tree)
+    pristine_tar_verify_orig(repo, cp, options, output_dir, orig_files)
 
 
 def pristine_tar_commit(repo, cp, options, output_dir, orig_file, upstream_tree):
@@ -239,6 +240,21 @@ def prepare_output_dir(dir):
     return output_dir
 
 
+def pristine_tar_prepare_orig_tree(repo, cp, options):
+    """Make sure the upstream tree exists
+    In case of component tarballs we need to recreate a tree for the
+    main tarball without the component subdirs.
+    """
+    if options.components:
+        try:
+            upstream_tag = repo.version_to_tag(options.upstream_tag, cp.upstream_version)
+            tree_name = "%s^{tree}" % upstream_tag
+            repo.tree_drop_dirs(tree_name, options.components)
+        except GitRepositoryError:
+            raise GbpError("Couldn't find upstream tree '%s' to create "
+                           "orig tarball via pristine-tar" % tree_name)
+
+
 def pristine_tar_build_orig(repo, cp, output_dir, options):
     """
     Build orig tarball using pristine-tar
@@ -250,17 +266,7 @@ def pristine_tar_build_orig(repo, cp, output_dir, options):
             gbp.log.warn('Pristine-tar branch "%s" not found' %
                          repo.pristine_tar.branch)
 
-        # Make sure the upstream tree exists, it might not be there in
-        # case of components since we don't keep a ref to it
-        if options.components:
-            try:
-                upstream_tag = repo.version_to_tag(options.upstream_tag, cp.upstream_version)
-                tree_name = "%s^{tree}" % upstream_tag
-                repo.tree_drop_dirs(tree_name, options.components)
-            except GitRepositoryError:
-                raise GbpError("Couldn't find upstream tree '%s' to create "
-                               "orig tarball via pristine-tar" % tree_name)
-
+        pristine_tar_prepare_orig_tree(repo, cp, options)
         try:
             repo.pristine_tar.checkout(cp.name,
                                        cp.upstream_version,
@@ -283,6 +289,21 @@ def pristine_tar_build_orig(repo, cp, output_dir, options):
     return False
 
 
+def pristine_tar_verify_orig(repo, cp, options, output_dir, orig_files):
+    """
+    Verify orig tarballs using prstine tar
+
+    @returns: C{True} if tarball was build, C{False} otherwise
+    """
+    if not options.pristine_tar:
+        return True
+
+    pristine_tar_prepare_orig_tree(repo, cp, options)
+    for f in orig_files:
+        repo.pristine_tar.verify(os.path.join(output_dir, f))
+    return True
+
+
 def get_upstream_tree(repo, cp, options):
     """Determine the upstream tree from the given options"""
     if options.upstream_tree.upper() == 'TAG':
@@ -318,12 +339,14 @@ def git_archive_build_orig(repo, cp, output_dir, options):
     gbp.log.info("Creating %s from '%s'" % (du.orig_file(cp,
                                                          options.comp_type),
                                             upstream_tree))
-    gbp.log.debug("Building upstream tarball with compression '%s -%s'" %
-                  (options.comp_type, options.comp_level))
-    main_tree = repo.tree_drop_dirs(upstream_tree, options.components)
+    comp_level = int(options.comp_level) if options.comp_level != '' else None
+    gbp.log.debug("Building upstream tarball with compression '%s'%s" %
+                  (options.comp_type,
+                   "' -%s'" % comp_level if comp_level is not None else ''))
+    main_tree = repo.tree_drop_dirs(upstream_tree, options.components) if options.components else upstream_tree
     if not git_archive(repo, cp, output_dir, main_tree,
                        options.comp_type,
-                       options.comp_level,
+                       comp_level,
                        options.with_submodules):
         raise GbpError("Cannot create upstream tarball at '%s'" % output_dir)
     for component in options.components:
@@ -336,7 +359,7 @@ def git_archive_build_orig(repo, cp, output_dir, options):
                         subtree))
         if not git_archive(repo, cp, output_dir, subtree,
                            options.comp_type,
-                           options.comp_level,
+                           comp_level,
                            options.with_submodules,
                            component=component):
             raise GbpError("Cannot create additional tarball %s at '%s'"
@@ -781,7 +804,7 @@ def main(argv):
         source = None
         retval = 1
     finally:
-        drop_index()
+        drop_index(repo)
 
     if not options.tag_only:
         if options.export_dir and options.purge and not retval:
