@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2010, 2012, 2015 Guido Günther <agx@sigxcpu.org>
+# (C) 2010,2012,2015,2016 Guido Günther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -204,11 +204,18 @@ def push_branches(remote, branches):
     gitPush([remote['url'], '--tags'])
 
 
+def usage_msg():
+    return """%prog [options] - create a remote git repository
+Actions:
+  create         create the repository. This is the default when no action is
+                 given.
+  list           list available configuration templates for remote repositories"""
+
+
 def build_parser(name, sections=[]):
     try:
         parser = GbpOptionParserDebian(command=os.path.basename(name), prefix='',
-                                       usage='%prog [options] - '
-                                       'create a remote repository',
+                                       usage=usage_msg(),
                                        sections=sections)
     except (GbpError, configparser.NoSectionError) as err:
         gbp.log.err(err)
@@ -251,44 +258,33 @@ def build_parser(name, sections=[]):
     return parser
 
 
-def parse_args(argv, sections=[]):
+def parse_args(argv):
     """
     Parse the command line arguments and config files.
 
     @param argv: the command line arguments
     @type argv: C{list} of C{str}
-    @param sections: additional sections to add to the config file parser
-        besides the command name
-    @type sections: C{list} of C{str}
     """
-
-    # We simpley handle the template section as an additional config file
+    sections = []
+    # We handle the template section as an additional config file
     # section to parse, this makes e.g. --help work as expected:
     for arg in argv:
         if arg.startswith('--remote-config='):
             sections = ['remote-config %s' % arg.split('=', 1)[1]]
             break
-    else:
-        sections = []
 
     parser = build_parser(argv[0], sections)
     if not parser:
-        return None, None
+        return None, None, None
 
-    return parser.parse_args(argv)
+    return list(parser.parse_args(argv)) + [parser.config_file_sections]
 
 
-def main(argv):
+def do_create(options):
     retval = 0
     changelog = 'debian/changelog'
     cmd = []
 
-    options, args = parse_args(argv)
-
-    if not options:
-        return ExitCodes.parse_error
-
-    gbp.log.setup(options.color, options.verbose, options.color_scheme)
     try:
         repo = DebianGitRepository(os.path.curdir)
     except GitRepositoryError:
@@ -359,9 +355,53 @@ def main(argv):
         if str(err):
             gbp.log.err(err)
         retval = 1
-
     return retval
 
+
+def get_config_names(sections):
+    config_names = []
+    for section in sections:
+        if section.startswith("remote-config "):
+            config_names.append(section.split(' ', 1)[1])
+    return config_names
+
+
+def do_list(sections):
+    names = get_config_names(sections)
+    if names:
+        gbp.log.info("Available remote config templates:")
+        for n in names:
+            print("    %s" % n)
+    else:
+        gbp.log.info("No remot config templates found.")
+    return 0
+
+
+def main(argv):
+    retval = 1
+
+    options, args, sections = parse_args(argv)
+    if not options:
+        return ExitCodes.parse_error
+
+    gbp.log.setup(options.color, options.verbose, options.color_scheme)
+
+    if len(args) == 1:
+        args.append('create')  # the default
+    elif len(args) > 2:
+        gbp.log.err("Only one action allowed")
+        return 1
+
+    action = args[1]
+    if action == 'create':
+        retval = do_create(options)
+    elif action == 'list':
+        retval = do_list(sections)
+    else:
+        gbp.log.err("Unknown action '%s'" % action)
+    return retval
+
+
 if __name__ == '__main__':
     sys.exit(main(sys.argv))
 
