@@ -18,9 +18,10 @@
 """Import a new upstream version into a Git repository"""
 
 import os
-import re
+import shutil
 import sys
 import tempfile
+import time
 import gbp.command_wrappers as gbpc
 from gbp.deb import (DebianPkgPolicy, parse_changelog_repo)
 from gbp.deb.upstreamsource import DebianUpstreamSource, unpack_component_tarball
@@ -32,7 +33,7 @@ from gbp.errors import GbpError
 from gbp.pkg import parse_archive_filename
 from gbp.format import format_str
 import gbp.log
-from gbp.scripts.common import ExitCodes
+from gbp.scripts.common import ExitCodes, is_download
 from gbp.scripts.common.import_orig import (orig_needs_repack, cleanup_tmp_tree,
                                             ask_package_name, ask_package_version,
                                             repack_source, is_link_target, download_orig)
@@ -198,6 +199,10 @@ def prepare_pristine_tar(archive, pkg, version):
     if os.path.basename(archive) != os.path.basename(link):
         try:
             if not is_link_target(archive, link):
+                if os.path.exists(link):
+                    backup = "%s.%d" % (link, time.time())
+                    gbp.log.info("%s already exists, moving to %s" % (link, backup))
+                    shutil.move(link, backup)
                 os.symlink(os.path.abspath(archive), link)
                 linked = True
         except OSError as err:
@@ -488,20 +493,6 @@ def parse_args(argv):
     return options, args
 
 
-def is_download(args):
-    """
-    >>> is_download(["http://foo.example.com"])
-    True
-    >>> is_download([])
-    False
-    >>> is_download(["foo-1.1.orig.tar.gz"])
-    False
-    """
-    if args and re.match("https?://", args[0]):
-        return True
-    return False
-
-
 def main(argv):
     ret = 0
     tmpdir = ''
@@ -535,7 +526,7 @@ def main(argv):
         else:
             source = find_source(options.uscan, args)
         if not source:
-            return ret
+            return ExitCodes.failed
 
         # The main tarball
         (sourcepackage, version) = detect_name_and_version(repo, source, options)
@@ -552,17 +543,19 @@ def main(argv):
         if repo.bare:
             set_bare_repo_options(options)
 
-        if not source.is_dir():
+        if not source.is_dir():  # Unpack main tarball
             tmpdir = tempfile.mkdtemp(dir='../')
             source.unpack(tmpdir, options.filters)
             gbp.log.debug("Unpacked '%s' to '%s'" % (source.path, source.unpacked))
-            for (component, tarball) in component_tarballs:
-                unpack_component_tarball(source.unpacked, component, tarball, options.filters)
 
         if orig_needs_repack(source, options):
             gbp.log.debug("Filter pristine-tar: repacking '%s' from '%s'" % (source.path, source.unpacked))
             (source, tmpdir) = repack_source(source, sourcepackage, version, tmpdir, options.filters)
 
+        if not source.is_dir():  # Unpack component tarballs
+            for (component, tarball) in component_tarballs:
+                unpack_component_tarball(source.unpacked, component, tarball, options.filters)
+
         (pristine_orig, linked) = prepare_pristine_tar(source.path,
                                                        sourcepackage,
                                                        version)
