@@ -157,9 +157,8 @@ def commit_patches(repo, branch, patches, options, patch_dir):
 
     vfs = gbp.git.vfs.GitVfs(repo, branch)
     try:
-        oldseries = vfs.open('debian/patches/series')
-        oldpatches = [p.strip() for p in oldseries.readlines()]
-        oldseries.close()
+        with vfs.open('debian/patches/series') as oldseries:
+            oldpatches = [p.strip() for p in oldseries.readlines()]
     except IOError:
         # No series file yet
         oldpatches = []
@@ -170,7 +169,7 @@ def commit_patches(repo, branch, patches, options, patch_dir):
     msg = format_series_diff(added, removed, options)
 
     if not repo.is_clean(paths='debian/patches')[0]:
-        repo.add_files(PATCH_DIR)
+        repo.add_files(PATCH_DIR, force=True)
         repo.commit_staged(msg=msg)
     return added, removed
 
