@@ -21,7 +21,9 @@ from . import testutils
 import os
 import unittest
 
-from gbp.scripts.pq import generate_patches, export_patches
+from gbp.command_wrappers import GitCommand
+from gbp.scripts.pq import (generate_patches, export_patches,
+                            import_quilt_patches, rebase_pq, SERIES_FILE)
 import gbp.scripts.common.pq as pq
 import gbp.patch_series
 
@@ -117,7 +119,7 @@ class TestWritePatch(testutils.DebianGitTestRepo):
         self.assertEqual(len(changes), len(expected_patches))
 
         d = context.new_tmpdir(__name__)
-        expected_paths = [os.path.join(str(d), n) for n in expected_patches ]
+        expected_paths = [os.path.join(str(d), n) for n in expected_patches]
 
         # Commit changes
         for c in changes:
@@ -148,14 +150,14 @@ class TestWritePatch(testutils.DebianGitTestRepo):
             renumber = False
             patch_num_format = '%04d-'
 
-        expected_patches = [ 'gbptest/added-foo.patch',
-                             'gbptest/patchname.diff' ]
+        expected_patches = ['gbptest/added-foo.patch',
+                            'gbptest/patchname.diff']
 
-        changes = [ ('foo', 'foo', ("added foo\n\n"
-                                    "Gbp-Pq: Topic gbptest")),
-                    ('baz', 'baz', ("added bar\n\n"
-                                    "Gbp-Pq: Topic gbptest\n"
-                                    "Gbp-Pq: Name patchname.diff")) ]
+        changes = [('foo', 'foo', ("added foo\n\n"
+                                   "Gbp-Pq: Topic gbptest")),
+                   ('baz', 'baz', ("added bar\n\n"
+                                   "Gbp-Pq: Topic gbptest\n"
+                                   "Gbp-Pq: Name patchname.diff"))]
 
         self._test_generate_patches(changes, expected_patches, opts)
 
@@ -167,14 +169,14 @@ class TestWritePatch(testutils.DebianGitTestRepo):
             renumber = True
             patch_num_format = '%02d_'
 
-        expected_patches = [ 'gbptest/01_added-foo.patch',
-                             'gbptest/02_patchname.diff' ]
+        expected_patches = ['gbptest/01_added-foo.patch',
+                            'gbptest/02_patchname.diff']
 
-        changes = [ ('foo', 'foo', ("added foo\n\n"
-                                    "Gbp-Pq: Topic gbptest")),
-                    ('baz', 'baz', ("added bar\n\n"
-                                    "Gbp-Pq: Topic gbptest\n"
-                                    "Gbp-Pq: Name 099-patchname.diff")) ]
+        changes = [('foo', 'foo', ("added foo\n\n"
+                                   "Gbp-Pq: Topic gbptest")),
+                   ('baz', 'baz', ("added bar\n\n"
+                                   "Gbp-Pq: Topic gbptest\n"
+                                   "Gbp-Pq: Name 099-patchname.diff"))]
 
         self._test_generate_patches(changes, expected_patches, opts)
 
@@ -186,30 +188,35 @@ class TestWritePatch(testutils.DebianGitTestRepo):
             renumber = True
             patch_num_format = '%02d_'
 
-        expected_patches = [ 'gbptest/added-foo.patch',
-                             'gbptest/patchname.diff',
-                             'gbptest/patchname-1.diff',
-                             'gbptest/patchname-2.diff' ]
+        expected_patches = ['gbptest/added-foo.patch',
+                            'gbptest/patchname.diff',
+                            'gbptest/patchname-1.diff',
+                            'gbptest/patchname-2.diff']
 
-        changes = [ ('foo', 'foo', ("added foo\n\n"
-                                    "Gbp-Pq: Topic gbptest")),
-                    ('baz', 'baz', ("added bar\n\n"
-                                    "Gbp-Pq: Topic gbptest\n"
-                                    "Gbp-Pq: Name 099-patchname.diff")),
-                    ('qux', 'qux', ("added qux\n\n"
-                                    "Gbp-Pq: Topic gbptest\n"
-                                    "Gbp-Pq: Name 100-patchname.diff")),
-                    ('norf', 'norf', ("added norf\n\n"
-                                      "Gbp-Pq: Topic gbptest\n"
-                                      "Gbp-Pq: Name 101-patchname.diff")) ]
+        changes = [('foo', 'foo', ("added foo\n\n"
+                                   "Gbp-Pq: Topic gbptest")),
+                   ('baz', 'baz', ("added bar\n\n"
+                                   "Gbp-Pq: Topic gbptest\n"
+                                   "Gbp-Pq: Name 099-patchname.diff")),
+                   ('qux', 'qux', ("added qux\n\n"
+                                   "Gbp-Pq: Topic gbptest\n"
+                                   "Gbp-Pq: Name 100-patchname.diff")),
+                   ('norf', 'norf', ("added norf\n\n"
+                                     "Gbp-Pq: Topic gbptest\n"
+                                     "Gbp-Pq: Name 101-patchname.diff"))]
 
         self._test_generate_patches(changes, expected_patches, opts)
 
 
 class TestExport(testutils.DebianGitTestRepo):
     class Options(object):
-        drop = True
+        drop = False
         patch_numbers = False
+        renumber = False
+        patch_num_format = ''
+        meta_closes = False
+        meta_closes_bugnum = ''
+        pq_from = 'DEBIAN'
 
     def setUp(self):
         testutils.DebianGitTestRepo.setUp(self)
@@ -220,12 +227,36 @@ class TestExport(testutils.DebianGitTestRepo):
         repo = self.repo
         start = repo.get_branch()
         pq_branch = os.path.join('patch-queue', start)
+        opts = TestExport.Options()
+        opts.drop = True
+
         pq.switch_pq(repo, start)
         self.assertEqual(repo.get_branch(), pq_branch)
-        export_patches(repo, pq_branch, TestExport.Options)
+        export_patches(repo, pq_branch, opts)
         self.assertEqual(repo.get_branch(), start)
         self.assertFalse(repo.has_branch(pq_branch))
 
+    def test_commit(self):
+        """Test if we commit the patch-queue branch with --commit"""
+        repo = self.repo
+        start = repo.get_branch()
+        pq_branch = os.path.join('patch-queue', start)
+        opts = TestExport.Options()
+        opts.commit = True
+        pq.switch_pq(repo, start)
+        self.assertEqual(len(repo.get_commits()), 1)
+        self.assertEqual(repo.get_branch(), pq_branch)
+        self.add_file('foo', 'foo')
+        export_patches(repo, pq_branch, opts)
+        self.assertEqual(repo.get_branch(), start)
+        self.assertTrue(repo.has_branch(pq_branch))
+        self.assertEqual(len(repo.get_commits()), 2,
+                         "Export did not create commit")
+        export_patches(repo, pq_branch, opts)
+        self.assertEqual(repo.get_branch(), start)
+        self.assertEqual(len(repo.get_commits()), 2,
+                         "Export must not create another commit")
+
 
 class TestParseGbpCommand(unittest.TestCase):
     def test_empty_body(self):
@@ -252,5 +283,121 @@ class TestParseGbpCommand(unittest.TestCase):
         self.assertEquals(body, 'Foo')
 
 
+class TestFromTAG(testutils.DebianGitTestRepo):
+    """Test L{gbp.pq}'s pq-from=TAG"""
+
+    class Options(object):
+        commit = True
+        drop = False
+        force = False
+        meta_closes = 'Closes|LP'
+        meta_closes_bugnum = r'(?:bug|issue)?\#?\s?\d+'
+        patch_num_format = '%04d-'
+        patch_numbers = False
+        pq_from = 'TAG'
+        renumber = False
+        upstream_tag = 'upstream/%(version)s'
+
+    def git_create_empty_branch(self, branch):
+        GitCommand('checkout', cwd=self.repo.path)(['-q', '--orphan', branch])
+        GitCommand('rm', cwd=self.repo.path)(['-rf', '.'])
+
+    def setUp(self):
+        testutils.DebianGitTestRepo.setUp(self)
+        self.add_file('debian/control')
+        self.add_file(
+            'debian/changelog',
+            'foo (0.0.1-1) UNRELEASED; urgency=medium\n'
+            '\n'
+            '  * Initial foo\n'
+            '\n'
+            ' -- Mr. T. S. <t@example.com>  '
+            'Thu, 01 Jan 1970 00:00:00 +0000\n'
+        )
+        self.git_create_empty_branch('bar')
+        self.add_file('foo', 'foo')
+        self.repo.create_tag('upstream/0.0.1')
+        self.repo.set_branch('master')
+
+    def test_empty(self):
+
+        import_quilt_patches(self.repo,
+                             branch=self.repo.get_branch(),
+                             series=SERIES_FILE,
+                             tries=1,
+                             force=TestFromTAG.Options.force,
+                             pq_from=TestFromTAG.Options.pq_from,
+                             upstream_tag=TestFromTAG.Options.upstream_tag)
+        diff = self.repo.diff(self.repo.get_branch(), 'upstream/0.0.1')
+        self.assertEqual('', diff)
+        diff = self.repo.diff(self.repo.get_branch(), 'master')
+        self.assertNotEqual('', diff)
+
+        rebase_pq(self.repo,
+                  branch=self.repo.get_branch(),
+                  pq_from=TestFromTAG.Options.pq_from,
+                  upstream_tag=TestFromTAG.Options.upstream_tag)
+        diff = self.repo.diff(self.repo.get_branch(), 'upstream/0.0.1')
+        self.assertEqual('', diff)
+        diff = self.repo.diff(self.repo.get_branch(), 'master')
+        self.assertNotEqual('', diff)
+
+        export_patches(self.repo,
+                       branch=self.repo.get_branch(),
+                       options=TestFromTAG.Options())
+        diff = self.repo.diff(self.repo.get_branch(), self.repo.head)
+        self.assertEqual('', diff)
+
+    def test_adding_patch(self):
+        import_quilt_patches(self.repo,
+                             branch=self.repo.get_branch(),
+                             series=SERIES_FILE,
+                             tries=1,
+                             force=TestFromTAG.Options.force,
+                             pq_from=TestFromTAG.Options.pq_from,
+                             upstream_tag=TestFromTAG.Options.upstream_tag)
+        self.add_file('bar', 'bar', 'added bar')
+        export_patches(self.repo,
+                       branch=self.repo.get_branch(),
+                       options=TestFromTAG.Options())
+        self.assertTrue(os.path.exists(os.path.join(self.repo.path,
+                                                    os.path.dirname(SERIES_FILE),
+                                                    'added-bar.patch')))
+        rebase_pq(self.repo,
+                  branch=self.repo.get_branch(),
+                  pq_from=TestFromTAG.Options.pq_from,
+                  upstream_tag=TestFromTAG.Options.upstream_tag)
+        export_patches(self.repo,
+                       branch=self.repo.get_branch(),
+                       options=TestFromTAG.Options())
+        self.assertTrue(os.path.exists(os.path.join(self.repo.path,
+                                                    os.path.dirname(SERIES_FILE),
+                                                    'added-bar.patch')))
+        # New upstream release
+        self.repo.set_branch('bar')
+        GitCommand('cherry-pick', cwd=self.repo.path)(['patch-queue/master'])
+        self.repo.create_tag('upstream/0.0.2')
+        self.repo.set_branch('master')
+        self.add_file(
+            'debian/changelog',
+            'foo (0.0.2-1) UNRELEASED; urgency=medium\n'
+            '\n'
+            '  * Initial foo\n'
+            '\n'
+            ' -- Mr. T. S. <t@example.com>  '
+            'Thu, 01 Jan 1970 00:00:00 +0000\n'
+        )
+        rebase_pq(self.repo,
+                  branch=self.repo.get_branch(),
+                  pq_from=TestFromTAG.Options.pq_from,
+                  upstream_tag=TestFromTAG.Options.upstream_tag)
+        export_patches(self.repo,
+                       branch=self.repo.get_branch(),
+                       options=TestFromTAG.Options())
+        self.assertFalse(os.path.exists(os.path.join(self.repo.path,
+                                                     os.path.dirname(SERIES_FILE),
+                                                     'added-bar.patch')))
+
+
 def _patch_path(name):
     return os.path.join(context.projectdir, 'tests/data', name)
