@@ -72,6 +72,21 @@ def test_empty():
     """
 
 
+def test_subdir():
+    """
+    Make surewe can init repos froma subdir
+    >>> import gbp.git, os
+    >>> os.mkdir(os.path.join(dirs['repo'], 'subdir'))
+    >>> repo = gbp.git.GitRepository(os.path.join(dirs['repo'], 'subdir'), toplevel=False)
+    >>> repo.path == dirs['repo']
+    True
+    >>> repo = gbp.git.GitRepository(os.path.join(dirs['repo'], 'subdir'), toplevel=True) # doctest:+ELLIPSIS
+    Traceback (most recent call last):
+    ...
+    GitRepositoryError: Not the toplevel of a Git repository at ...
+    """
+
+
 def test_add_files():
     """
     Add some dummy data
@@ -739,7 +754,7 @@ def test_create_bare():
     >>> bare = gbp.git.GitRepository.create(dirs['bare'], bare=True, description="msg")
     >>> bare.path == dirs['bare']
     True
-    >>> bare.git_dir[:-1] == dirs['bare']
+    >>> bare.git_dir == dirs['bare']
     True
     >>> type(bare) == gbp.git.GitRepository
     True
@@ -823,7 +838,7 @@ def test_checkout():
 
 def test_gc():
     """
-    Test garbace collection
+    Test garbage collection
 
     Methods tested:
          - L{gbp.git.GitRepository.collect_garbage}
@@ -831,6 +846,8 @@ def test_gc():
     >>> import gbp.git
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.collect_garbage()
+    >>> repo.collect_garbage(prune=True)
+    >>> repo.collect_garbage(prune='all', aggressive=True)
     """
 
 
@@ -1019,4 +1036,18 @@ def test_set_user_name_and_email():
     >>> repo.set_user_email("stapelberg@test.invalid")
     """
 
+
+def test_git_dir():
+    """
+    Properties tested:
+        - L{gbp.git.GitRepository.git_dir}
+    >>> import os, gbp.git
+    >>> git_dir = os.path.join(dirs['repo'], '.git')
+    >>> os.environ['GIT_DIR'] = git_dir
+    >>> somewhere = gbp.git.GitRepository(os.path.join(dirs['repo'], '..'))
+    >>> somewhere.git_dir == git_dir
+    True
+    >>> del os.environ['GIT_DIR']
+    """
+
 # vim:et:ts=4:sw=4:et:sts=4:ai:set list listchars=tab\:»·,trail\:·:
